package net.dotmyself.bartering;

import java.net.URI;
import java.util.List;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.GenericType;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import net.dotmyself.file.source._13.model.Person;
import net.dotmyself.file.source._13.model.Service;

/**
 * Java client for the Bartering's restful web service
 *
 * @author hyacinthe MENIET
 */
public class App {

    private static final String REST_URL = "http://localhost:8080/bartering/api/persons";
    private static final String BGID = "1";
    private static final String SJID = "2";
    private static final String SERVICE_URI = "services";

    public static void main(String[] args) {

        Client client = ClientBuilder.newClient();
        WebTarget target = client.target(REST_URL);
        Service createdService;
        URI CreatedServiceUri;
        WebTarget createdServiceTarget;
        Person SteveJobs;

        System.out.println("Reading the person Bill Gates ...");
        try (Response response = target.path(BGID).request(MediaType.APPLICATION_XML).get()) {
            Person BillGates = response.readEntity(Person.class);
            System.out.println(response.getStatus());
            System.out.println(BillGates);
            System.out.println();
        }

        System.out.println("Reading the person Steve Jobs ...");
        try (Response response = target.path(SJID).request(MediaType.APPLICATION_XML).get()) {
            SteveJobs = response.readEntity(Person.class);
            System.out.println(response.getStatus());
            System.out.println(SteveJobs);
            System.out.println();
        }

        System.out.println("Adding a Service to the person Steve Jobs ...");
        createdService = new Service("Telechargement de 3 morceaux sur l'Apple Music Store");
        try (Response response = target.path(SJID).path(SERVICE_URI).request(MediaType.APPLICATION_XML)
                .post(Entity.entity(createdService, MediaType.APPLICATION_XML))) {
            CreatedServiceUri = response.getLocation();
            System.out.println(response.getStatus());
            System.out.println();
        }

        System.out.println("Reading the list of services from the person Steve Jobs ...");
        try (Response response = target.path(SJID).path(SERVICE_URI).request(MediaType.APPLICATION_XML).get()) {
            List<Service> services = response.readEntity(new GenericType<List<Service>>() {
            });
            System.out.println(response.getStatus());
            System.out.println(services);
            System.out.println();
        }

        System.out.println("Reading one service from the person Steve Jobs ...");
        createdServiceTarget = client.target(CreatedServiceUri);
        try (Response response = createdServiceTarget.request(MediaType.APPLICATION_XML).get()) {
            createdService = response.readEntity(Service.class);
            System.out.println(response.getStatus());
            System.out.println(createdService);
            System.out.println();
        }

        System.out.println("Updating one service from the person Steve Jobs ...");
        createdService = new Service("1 Entree pour le concert : Flash Haters");
        try (Response response = createdServiceTarget.request(MediaType.APPLICATION_XML)
                .put(Entity.entity(createdService, MediaType.APPLICATION_XML))) {
            System.out.println(response.getStatus());
            System.out.println();
        }

        System.out.println("Re-reading one service from the person Steve Jobs ...");
        try (Response response = createdServiceTarget.request(MediaType.APPLICATION_XML).get()) {
            createdService = response.readEntity(Service.class);
            System.out.println(response.getStatus());
            System.out.println(createdService);
            System.out.println();
        }

        System.out.println("Deleting one service from the person Steve Jobs ...");
        try (Response response = createdServiceTarget.request(MediaType.APPLICATION_XML).delete()) {
            System.out.println(response.getStatus());
            System.out.println();
        }

        System.out.println("Re-reading the person Steve Jobs ...");
        try (Response response = target.path(SJID).request(MediaType.APPLICATION_XML).get()) {
            SteveJobs = response.readEntity(Person.class);
            System.out.println(response.getStatus());
            System.out.println(SteveJobs);
            System.out.println();
        }
    }
}
