package net.dotmyself.bartering.service;

import java.net.URI;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.persistence.EntityGraph;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.EntityTransaction;
import javax.persistence.Persistence;
import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.NotFoundException;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import net.dotmyself.file.source._13.model.Service;
import net.dotmyself.file.source._13.model.Person;

/**
 *
 * The Service resource that returns service's informations.
 *
 * @author Hyacinthe MENIET
 */
public class ServiceResource {

    private final int personId;

    public ServiceResource(int pid) {
        this.personId = pid;
    }

    @GET
    @Produces(MediaType.APPLICATION_XML)
    public List<Service> getServices() {

        EntityManagerFactory emf = Persistence
                .createEntityManagerFactory(Person.PERSISTENCE_UNIT);
        EntityManager em = emf.createEntityManager();
        
        EntityGraph graph = em.getEntityGraph("graph.Person.services");
        Map hints = new HashMap();
        hints.put("javax.persistence.fetchgraph", graph);
        
        Person p = em.find(Person.class, this.personId, hints);
        if (null == p) {
            emf.close();
            throw new NotFoundException("person with personId=" + this.personId
                    + " does not exist!");
        }
        emf.close();
        return p.getServices();
    }

    @GET
    @Path("{id : \\d+}")
    @Produces(MediaType.APPLICATION_XML)
    public Service getService(@PathParam("id") int id) {

        Service s;
        EntityManagerFactory emf;
        emf = Persistence
                .createEntityManagerFactory(Person.PERSISTENCE_UNIT);
        s = (Service) emf.createEntityManager().createNamedQuery(Service.FIND_BY_PERSON).setParameter("serviceId", id)
                .setParameter("personId", this.personId).getSingleResult();
        emf.close();
        return s;
    }

    @POST
    @Consumes(MediaType.APPLICATION_XML)
    public Response createService(Service s) {

        EntityManagerFactory emf = Persistence
                .createEntityManagerFactory(Person.PERSISTENCE_UNIT);
        EntityManager em = emf.createEntityManager();
        EntityTransaction tx = em.getTransaction();
        tx.begin();

        Person p = em.find(Person.class, this.personId);
        s.setId(0);
        s.setPerson(p);
        em.persist(s);

        tx.commit();
        em.close();
        emf.close();

        return Response.created(URI.create("/bartering/api/persons/"+this.personId
                +"/services/" + s.getId())).build();
    }

    @PUT
    @Path("{id : \\d+}")
    @Consumes(MediaType.APPLICATION_XML)
    public void updateService(@PathParam("id") int id, Service extService) {

        EntityManagerFactory emf = Persistence
                .createEntityManagerFactory(Person.PERSISTENCE_UNIT);
        EntityManager em = emf.createEntityManager();
        EntityTransaction tx = em.getTransaction();
        tx.begin();

        Service intService = em.find(Service.class, id);
        if (null == intService) {
            throw new NotFoundException("service with personId="
                    + this.personId + " and serviceId=" + id + " not found");
        }
        intService.setDescription(extService.getDescription());
        em.merge(intService);

        tx.commit();
        em.close();
        emf.close();
    }

    @DELETE
    @Path("{id : \\d+}")
    public void deleteService(@PathParam("id") int id) {

        EntityManagerFactory emf = Persistence
                .createEntityManagerFactory(Person.PERSISTENCE_UNIT);
        EntityManager em = emf.createEntityManager();
        EntityTransaction tx = em.getTransaction();
        tx.begin();

        Service s = em.find(Service.class, id);
        if (null != s) {
            em.remove(s);
        }

        tx.commit();
        em.close();
        emf.close();

    }

}
