package net.dotmyself.file.source._13.model;

import java.io.Serializable;
import java.util.List;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.NamedAttributeNode;
import javax.persistence.NamedEntityGraph;
import javax.persistence.OneToMany;
import javax.persistence.OrderBy;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * The persistent class for the person database table.
 *
 * @author Hyacinthe MENIET
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "name",
    "firstname",
    "location",
    "services"
})
@XmlRootElement(name = "person")
@Entity
@NamedEntityGraph(name = "graph.Person.services",
        attributeNodes = @NamedAttributeNode("services"))
@Table(name = "person")
public class Person implements Serializable {
    
    private static final long serialVersionUID = 1L;
    public static final String PERSISTENCE_UNIT = "BarteringPU";

    @XmlElement(required = true)
    @Column(nullable = false)
    protected String name;
    
    @XmlElement(required = false)
    @Column(nullable = true)
    protected String firstname;
    
    @XmlElement(required = false)
    @Column(nullable = true)
    protected String location;
    
    // bi-directional many-to-one association to Service
    @XmlElement(name = "service", required = true)
    @XmlElementWrapper(name = "services", required = true)
    @OneToMany(fetch = FetchType.LAZY, cascade = CascadeType.ALL)
    @JoinColumn(name = "person_id", insertable = true, updatable = true)
    @OrderBy("id ASC")
    protected List<Service> services;
    
    @XmlAttribute(name = "id")
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    protected int id;

    public Person() {
    }
   
    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the firstname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFirstname() {
        return firstname;
    }

    /**
     * Sets the value of the firstname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFirstname(String value) {
        this.firstname = value;
    }

    /**
     * Gets the value of the location property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLocation() {
        return location;
    }

    /**
     * Sets the value of the location property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLocation(String value) {
        this.location = value;
    }

    /**
     * Gets a reference to the list of services property.
     * 
     * @return
     *     possible objects of the following type(s)
     *     {@link Service }
     *     
     */
    public List<Service> getServices() {
        return services;
    }

    /**
     * Sets the value of the list of services property.
     * 
     * @param value
     *     Objects of the following type(s) are allowed in the list
     *     {@link Service }
     *     
     */
    public void setServices(List<Service> value) {
        this.services = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible value type is
     *     {@link int }
     *     
     */
    public int getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed value type is
     *     {@link int }
     *     
     */
    public void setId(int value) {
        this.id = value;
    }   
}
