package net.dotmyself.file.source._13.model;

import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;

/**
 * The persistent class for the service database table.
 *
 * @author Hyacinthe MENIET
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "description"
})
@XmlRootElement(name = "service")
@Entity
@Table(name = "service")
@NamedQuery(name = Service.FIND_BY_PERSON,
        query = "SELECT s FROM Service s WHERE s.id = :serviceId AND s.person.id = :personId")
public class Service implements Serializable {
    
    private static final long serialVersionUID = 1L;
    public static final String FIND_BY_PERSON = "Service.finByPerson";

    @XmlElement(required = true)
    @Lob()
    @Column(nullable = false)
    protected String description;
    
    @XmlAttribute(name = "id")
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    protected int id;
    
    //bi-directional many-to-one association to Member
    @XmlTransient
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "person_id")
    protected Person person;

    public Service() {
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible value type is
     *     {@link int }
     *     
     */
    public int getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed value type is
     *     {@link int }
     *     
     */
    public void setId(int value) {
        this.id = value;
    }

    /**
     * Gets the value of the Person property.
     *
     * @return
     *     possible object is
     *     {@link Person }
     *
     */
    public Person getPerson() {
        return person;
    }

    /**
     * Sets the value of the Person property.
     *
     * @param value
     *     allowed object is
     *     {@link Person }
     *
     */
    public void setPerson(Person value) {
        this.person = value;
    }

}
